pub enum LambertPath {
ZeroRevolution,
Left,
Right,
}Expand description
Deterministic position of a solution within its revolution family.
Variants
ZeroRevolution
The unique zero-revolution solution.
Left
Multi-revolution solution on the left side of minimum time.
Right
Multi-revolution solution on the right side of minimum time.